@@ -1,9 +1,9 @@
 #' Coercion from messy dates
 #'
 #' @description
-#' These functions coerce objects of `messydt` class to
+#' These functions coerce objects of `mdate` class to
 #' common date classes such as `Date`, `POSIXct`, and `POSIXlt`.
-#' Since `messydt` objects can hold multiple individual dates,
+#' Since `mdate` objects can hold multiple individual dates,
 #' however, an additional function must be passed as an argument
 #' so that these functions know how to coerce resolve multiple dates
 #' into a single date.
@@ -11,13 +11,13 @@
 #' For example, one might wish to use the earliest possible date
 #' in any ranges of dates (`min`), the latest possible date (`max`),
 #' some notion of a central tendency (`mean`, `median`, or `modal`),
-#' or even a `random` selection from amongst the candidate dates.
+#' or even a `random` selection from among the candidate dates.
 #'
 #' These functions then, building on `expand()` and the resolve functions,
-#' are particularly useful in converting back out of the `messydt` class
+#' are particularly useful in converting back out of the `mdate` class
 #' for use with existing methods and models,
 #' especially for checking the robustness of results.
-#' @param x A `messydt` object
+#' @param x A `mdate` object
 #' @param ... Arguments passed on to the S3 generics.
 #' @param FUN A function that can be used to resolve expanded messy dates
 #' into a single date.
@@ -41,7 +41,7 @@ NULL
 #' as.Date(as_messydate("1000 BC"), median)
 #' as.Date(as_messydate(c("-1000", "2020")), min)
 #' @export
-as.Date.messydt <- function(x, ..., FUN) {
+as.Date.mdate <- function(x, ..., FUN) {
   if (missing(FUN) & length(list(...)) > 0) FUN <- list(...)[[1]]
   x <- FUN(x)
   x <- ifelse(stringr::str_detect(x, "^-"),
@@ -52,29 +52,28 @@ as.Date.messydt <- function(x, ..., FUN) {
 
 #' @rdname from_messydate
 #' @export
-as.POSIXct.messydt <- function(x, ..., FUN) {
+as.POSIXct.mdate <- function(x, ..., FUN) {
   if (missing(FUN) & length(list(...)) > 0) FUN <- list(...)[[1]]
   x <- FUN(x)
   if (stringr::str_detect(x, "^-")) {
-    stop("For conversion of negative dates from messydt class use as.Date()")
+    stop("For conversion of negative dates from mdate class use as.Date()")
   }
   as.POSIXct(x)
 }
 
 #' @rdname from_messydate
 #' @export
-as.POSIXlt.messydt <- function(x, ..., FUN) {
+as.POSIXlt.mdate <- function(x, ..., FUN) {
   if (missing(FUN) & length(list(...)) > 0) FUN <- list(...)[[1]]
   x <- FUN(x)
   if (stringr::str_detect(x, "^-")) {
-    stop("For conversion of negative dates from messydt class use as.Date()")
+    stop("For conversion of negative dates from mdate class use as.Date()")
   }
   as.POSIXlt(x)
 }
 
-#' Helper function for returning negative dates in date formats
-#' @rdname from_messydate
-#' @importFrom stringr str_remove str_replace
+# Helper function for returning negative dates in date formats
+#' @importFrom stringr str_detect str_replace str_remove str_extract
 #' @importFrom lubridate ymd years as_date
 negative_dates <- function(x) {
   x <- ifelse(stringr::str_detect(x, "^-[0-9]{3}-"),
